@@ -7,7 +7,7 @@ use File::Spec;
 use strict;
 use warnings;
 
-$Neo4j::Client::VERSION="0.12";
+$Neo4j::Client::VERSION="0.15";
 
 $Neo4j::Client::LIBS =
   join(' ', "-L".realpath(module_dir(__PACKAGE__))." -lClient",
@@ -17,8 +17,13 @@ $Neo4j::Client::CCFLAGS =
   join(' ', "-I".realpath(module_dir(__PACKAGE__)),
        $Neo4j::Client::LOCAL_CCFLAGS);
 
+$Neo4j::Client::DEV_CCFLAGS =
+  join(' ',"-I".realpath(module_dir(__PACKAGE__))."/include",
+       $Neo4j::Client::CCFLAGS);
+       
 sub Neo4j::Client::LIBS_ARY { split /\s+/,$Neo4j::Client::LIBS }
 sub Neo4j::Client::CCFLAGS_ARY { split /\s+/,$Neo4j::Client::CCFLAGS }
+sub Neo4j::Client::DEV_CCFLAGS_ARY { split /\s+/,$Neo4j::Client::DEV_CCFLAGS }
 
 sub dir { realpath(module_dir(__PACKAGE__)) }
 
@@ -52,6 +57,43 @@ to fold the library in to compilation and linking.
 
 The script C<neoclient.pl> will provide these on the command line.
 
+=head1 VARIABLES
+
+=over
+
+=item $Neo4j::Client::LIBS
+
+=item $Neo4j::Client::CCFLAGS
+
+=item $Neo4j::Client::DEV_CCFLAGS
+
+CCFLAGS plus an '-I' flag pointing to installed E<lt>archE<gt>/auto/Neo4j/Client/include,
+which contains config.h for the build and all libneo4j-client src/lib/*.h files.
+
+=back
+
+=head1 FUNCTIONS
+
+=over
+
+=item Neo4j::Client::LIBS_ARY()
+
+LIBS tokenized as plain array.
+
+=item Neo4j::Client::CCFLAGS_ARY()
+
+CCFLAGS tokenized as plain array.
+
+=item Neo4j::Client::DEV_CCFLAGS_ARY()
+
+DEV_CCFLAGS tokenized as plain array.
+
+=item Neo4j::Client::dir()
+
+Absolute path to installed E<lt>archE<gt>/auto/Neo4j/Client.
+
+=back
+
 =head1 SEE ALSO
 
 L<Neo4j::Bolt>.
